@@ -20,6 +20,8 @@ import osaft.solutions.doinikov1994rigid as doinikov1994rigid
 import osaft.solutions.doinikov1994compressible as doinikov1994compressible
 import osaft.solutions.settnes2012 as settnes2012
 import osaft.solutions.hasegawa1969 as hasegawa1969
+import osaft.solutions.doinikov2021viscous as doinikov2021viscous
+import osaft.solutions.doinikov2021viscoelastic as doinikov2021viscoelastic
 
 # Legacy names of modules
 Gorkov1962 = gorkov1962
@@ -28,4 +30,6 @@ Yosioka1955 = yosioka1955
 Doinikov1994Rigid = doinikov1994rigid
 Doinikov1994Compressible = doinikov1994compressible
 Settnes2012 = settnes2012
+Doinikov2021Viscous = doinikov2021viscous
+Doinikov2021Viscoelastic = doinikov2021viscoelastic
 Hasegawa1969 = hasegawa1969
