@@ -245,9 +245,11 @@ class BaseDoinikov1994(BaseSphereFrequencyComposite):
         """
         return self.field.abs_pos
 
-    def A_in(self, n) -> complex:
+    def A_in(self, n: int) -> complex:
         """Wraps to
         :attr:`osaft.core.backgroundfields.BackgroundField.A_in`
+
+        :param n: mode number
         """
         return self.field.A_in(n)
 
