@@ -34,7 +34,7 @@ class ARF(ARFArbitraryRadius):
     :param wave_type: Type of wave, traveling or standing
     :param position: Position within the standing wave field [m]
     :param small_boundary_layer: :math:`x \\ll x_v \\ll 1`
-    :param large_boundary_layer: :math`x \\ll 1 \\ll x_v`
+    :param large_boundary_layer: :math:`x \\ll 1 \\ll x_v`
     :param N_max: Highest order mode
     :param background_streaming: background streaming contribution
     """
