@@ -137,8 +137,6 @@ class TestARFGeneral(BaseTestARF):
                 self.cls.L_n_l(n, 1)
                 + self.cls.L_n_l(n, 2)
             ) / 2
-            print(f'{first = }')
-            print(f'{second = }')
             self.assertAlmostEqual(abs(first), abs(second), 1e-2)
 
     @unittest.skip('Test not working due to numerical problems.')
